/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TCentralComponent.h"
//---------------------------------------------------------------------
#define tr(s) String::fromUTF8(s)
//---------------------------------------------------------------------
TCentralComponent::TCentralComponent() : Component("Central Component"),
                                         pFontViewer(0),
                                         pFontNameLabel(0),
                                         pFontsBox(0),
                                         pFontSizeLabel(0),
                                         pFontSizeBox(0),
                                         pFontStyleLabel(0),
                                         pFontGroup(0),
                                         pNormalButton(0),
                                         pBoldButton(0),
                                         pItalicButton(0)
{
    pFontViewer = new TextEditor("FontViewer");
    // Поле ввода - многострочное
    pFontViewer->setMultiLine(true);
    // Новая строка при нажатии клавиши <ENTER>
    pFontViewer->setReturnKeyStartsNewLine(true);
    // Запрет на редактирование
    pFontViewer->setReadOnly(true);
    // Показать полосы прокрутки
    pFontViewer->setScrollbarsShown(true);
    pFontViewer->setText(tr("Съешь же ещё этих мягких французских булок да выпей чаю.\n1234567890\n`~@#$%^&*()-_=+\\|{[]};:'\"/?"));
    addAndMakeVisible(pFontViewer);
  
    pFontNameLabel = new Label("FontNameLabel", tr("Гарнитура (вид) шрифта"));
    pFontNameLabel->setFont(Font(15.0000f, Font::plain));
    pFontNameLabel->setJustificationType(Justification::centredLeft);
    pFontNameLabel->setEditable(false, false, false);
    pFontNameLabel->setColour(Label::textColourId, Colours::black);
    pFontNameLabel->setColour(Label::backgroundColourId, Colour(Colours::azure));
    addAndMakeVisible(pFontNameLabel);
    
    pFontsBox = new ComboBox("FontsBox");
    // Запрет на редактирование текста в выпадающем списке
    pFontsBox->setEditableText(false);
    // Выравнивание теста по левому краю и центру виджета
    pFontsBox->setJustificationType(Justification::centredLeft);
    pFontsBox->setTextWhenNothingSelected(tr("Стандартный шрифт"));
    // Устанавливаем в качестве слушателя списка
    // сам компонент-контейнер
    pFontsBox->addListener (this);
    addAndMakeVisible(pFontsBox);
    
    // Получаем имена системных шрифтов, сохраняем их 
    // в строковом массиве...
    StringArray sSystemFonts = Font::findAllTypefaceNames();
    // и добавляем в выпадающий список
    for(int i = 0; i < sSystemFonts.size(); i++)
    {
        pFontsBox->addItem(sSystemFonts[i], i + 1);
    }

    pFontSizeLabel = new Label("FontSizeLabel", tr("Размер (кегль) шрифта"));
    pFontSizeLabel->setFont(Font(15.0000f, Font::plain));
    pFontSizeLabel->setJustificationType(Justification::centredLeft);
    pFontSizeLabel->setEditable(false, false, false);
    pFontSizeLabel->setColour(Label::textColourId, Colours::black);
    pFontSizeLabel->setColour(Label::backgroundColourId, Colour(Colours::azure));
    addAndMakeVisible(pFontSizeLabel);
    
    pFontSizeBox = new ComboBox("FontSizeBox");
    pFontSizeBox->setEditableText(false);
    pFontSizeBox->setJustificationType(Justification::centredLeft);
    pFontSizeBox->setTextWhenNothingSelected(tr("Размер по умолчанию"));
    pFontSizeBox->addItem("8", 1);
    pFontSizeBox->addItem("9", 2);
    pFontSizeBox->addItem("10", 3);
    pFontSizeBox->addItem("11", 4);
    pFontSizeBox->addItem("12", 5);
    pFontSizeBox->addItem("13", 6);
    pFontSizeBox->addItem("14", 7);
    pFontSizeBox->addItem("15", 8);
    pFontSizeBox->addItem("16", 9);
    pFontSizeBox->addItem("17", 10);
    pFontSizeBox->addItem("18", 11);
    pFontSizeBox->addItem("19", 12);
    pFontSizeBox->addItem("20", 13);
    // Устанавливаем в качестве слушателя списка
    // сам компонент-контейнер
    pFontSizeBox->addListener (this);
    addAndMakeVisible(pFontSizeBox);
    
    pFontStyleLabel = new Label("FontStyleLabel", tr("Стиль шрифта"));
    pFontStyleLabel->setFont(Font(15.0000f, Font::plain));
    pFontStyleLabel->setJustificationType(Justification::centredLeft);
    pFontStyleLabel->setEditable(false, false, false);
    pFontStyleLabel->setColour(Label::textColourId, Colours::black);
    pFontStyleLabel->setColour(Label::backgroundColourId, Colour(Colours::azure));
    addAndMakeVisible(pFontStyleLabel);
    
    pFontGroup = new GroupComponent("FontGroup", tr("Шрифт"));
    pFontGroup->setTextLabelPosition(Justification::centredLeft);
    addAndMakeVisible(pFontGroup);
    
    pNormalButton = new ToggleButton("NormalButton");
    pNormalButton->setButtonText(tr("Нормальный"));
    // Устанавливаем в качестве слушателя кнопки
    // сам компонент-контейнер
    pNormalButton->addListener(this);
    // Радиокнопка отмечена
    pNormalButton->setToggleState(true, false);
    pNormalButton->setRadioGroupId(1234);
    addAndMakeVisible(pNormalButton);
    
    pBoldButton = new ToggleButton("BoldButton");
    pBoldButton->setButtonText(tr("Полужирный"));
    pBoldButton->addListener(this);
    // Радиокнопка не отмечена
    pBoldButton->setToggleState(false, false);
    pBoldButton->setRadioGroupId(1234);
    addAndMakeVisible(pBoldButton);
    
    pItalicButton = new ToggleButton("ItalicButton");
    pItalicButton->setButtonText(tr("Курсив"));
    pItalicButton->addListener(this);
    pItalicButton->setToggleState(false, false);
    pItalicButton->setRadioGroupId(1234);
    addAndMakeVisible(pItalicButton);

    setSize (600, 400);
}
//---------------------------------------------------------------------
TCentralComponent::~TCentralComponent()
{
    // Удаляем дочерние виджеты
    // и обнуляем их указатели
    deleteAllChildren();
}
//---------------------------------------------------------------------
void TCentralComponent::paint(Graphics& Canvas)
{
    Canvas.fillAll(Colours::azure);
}
//---------------------------------------------------------------------
void TCentralComponent::resized()
{
    pFontViewer->setBounds(proportionOfWidth(0.5505f), 8, proportionOfWidth(0.4192f), proportionOfHeight(0.9507f));
    pFontNameLabel->setBounds(8, 8, roundFloatToInt((proportionOfWidth(0.4192f)) * 1.2048f), 25);
    pFontsBox->setBounds(8, 38, roundFloatToInt((proportionOfWidth(0.4192f)) * 1.2048f), 25);
    pFontSizeLabel->setBounds (8, 68, roundFloatToInt((proportionOfWidth(0.4192f)) * 1.2048f), 25);
    pFontSizeBox->setBounds(8, 96, roundFloatToInt((proportionOfWidth(0.4192f)) * 1.2048f), 25);
    pFontStyleLabel->setBounds(8, 126, roundFloatToInt((proportionOfWidth(0.4192f)) * 1.2048f), 25);
    pFontGroup->setBounds(8, 156, roundFloatToInt((proportionOfWidth(0.4192f)) * 1.2048f), 196);
    pNormalButton->setBounds(32, 185, 150, 25);
    pBoldButton->setBounds(32, 216, 150, 25);
    pItalicButton->setBounds(32, 248, 150, 25);
}
//---------------------------------------------------------------------
void TCentralComponent::comboBoxChanged(ComboBox* pComboBox)
{
    // Изменён выпадающий список гарнитуры шрифта
    if(pComboBox == pFontsBox)
    {
        // Устанавливаем в качестве шрифта текста поля ввода
        // шрифт, выбранный пользователем из списка
        CurrentFont.setTypefaceName(pFontsBox->getText());
    }
    // Изменён выпадающий список размера шрифта
    else if(pComboBox == pFontSizeBox)
    {
        // Вычисляем размер шрифта в пикселях,
        // исходя из выбранного пользователем кегля в типографских пунктах
        float fFontHeight = pFontSizeBox->getText().getFloatValue() * 96 / 72;
        // Устанавливаем размер шрифта
        CurrentFont.setHeight(fFontHeight);
    }
    // Задаём шрифт для отображения текста
    pFontViewer->applyFontToAllText(CurrentFont);
}
//---------------------------------------------------------------------
void TCentralComponent::buttonClicked(Button* pButton)
{
    if (pButton == pNormalButton)
    {
        /*if(CurrentFont.isBold())
        {
            CurrentFont.setBold(false);
        }
        else if(CurrentFont.isItalic())
        {
            CurrentFont.setItalic(false);  
        }*/
        
        // Задаём стиль шрифта - нормальный
        CurrentFont.setStyleFlags(Font::plain);
    }
    else if (pButton == pBoldButton)
    {
        /*if(CurrentFont.isItalic())
        {
            CurrentFont.setItalic(false);
        }
        CurrentFont.setBold(true);*/
        
        // Задаём стиль шрифта - полужирный
        CurrentFont.setStyleFlags(Font::bold);
    }
    else if (pButton == pItalicButton)
    {
        /*if(CurrentFont.isBold())
        {
            CurrentFont.setBold(false);
        }
        CurrentFont.setItalic(true);*/
        
        // Задаём стиль шрифта - курсив
        CurrentFont.setStyleFlags(Font::italic);
    }
    pFontViewer->applyFontToAllText(CurrentFont);
}
//---------------------------------------------------------------------
